==> ejc-businessplan-impl-3.0.0-20230314.074103-119-sources.jar: com/ejianc/business/change/vo/ChangeFundsplanningdetailVO.java <==
package com.ejianc.business.change.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 项目资金管理策划变更子表
 *
 * @author generator
 *
 */
public class ChangeFundsplanningdetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long mid; // 主表id
    private String sort; // 序号
    private java.util.Date collectbranchTime; // 收支时间(日期)
    private java.lang.String collectbranchTime1; // 收支时间(文本)
    private String imagenode; // 形象进度节点情况
    private java.math.BigDecimal plancomplete; // 计划完成产值
    private java.math.BigDecimal civilengineering; // 土建
    private java.math.BigDecimal installation; // 安装
    private java.math.BigDecimal other; // 其它
    private java.math.BigDecimal labourservices; // 劳务
    private java.math.BigDecimal material; // 材料
    private java.math.BigDecimal professional; // 专业分包
    private java.math.BigDecimal othercost; // 其它费用
    private java.math.BigDecimal current; // 当期
    private java.math.BigDecimal cumulative; // 累计
    private java.math.BigDecimal answer; // 应对措施
    private String remarks; // 备注
    private java.math.BigDecimal salary; // 工资
    private java.math.BigDecimal cioAmount; // 土建安装其他总计
    private java.util.Date effectTime; // 生效时间
    private String changeReason; // 变更原因
    private String billCode;
    private String errorMsg;

    private java.lang.Integer pastFlag;//是否为往期数据：1是，0否

    public String getErrorMsg() {
        return errorMsg;
    }

    public void setErrorMsg(String errorMsg) {
        this.errorMsg = errorMsg;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    /**
     * 主表id
     */
    public Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(Long mid) {
        this.mid = mid;
    }
    /**
     * 序号
     */
    public String getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(String sort) {
        this.sort = sort;
    }
    /**
     * 收支时间(日期)
     */
    public java.util.Date getCollectbranchTime() {
        return collectbranchTime;
    }

    /**
     * 收支时间(日期)
     */
    public void setCollectbranchTime(java.util.Date collectbranchTime) {
        this.collectbranchTime = collectbranchTime;
    }
    /**
     * 形象进度节点情况
     */
    public String getImagenode() {
        return imagenode;
    }

    /**
     * 形象进度节点情况
     */
    public void setImagenode(String imagenode) {
        this.imagenode = imagenode;
    }
    /**
     * 计划完成产值
     */
    public java.math.BigDecimal getPlancomplete() {
        return plancomplete;
    }

    /**
     * 计划完成产值
     */
    public void setPlancomplete(java.math.BigDecimal plancomplete) {
        this.plancomplete = plancomplete;
    }
    /**
     * 土建
     */
    public java.math.BigDecimal getCivilengineering() {
        return civilengineering;
    }

    /**
     * 土建
     */
    public void setCivilengineering(java.math.BigDecimal civilengineering) {
        this.civilengineering = civilengineering;
    }
    /**
     * 安装
     */
    public java.math.BigDecimal getInstallation() {
        return installation;
    }

    /**
     * 安装
     */
    public void setInstallation(java.math.BigDecimal installation) {
        this.installation = installation;
    }
    /**
     * 其它
     */
    public java.math.BigDecimal getOther() {
        return other;
    }

    /**
     * 其它
     */
    public void setOther(java.math.BigDecimal other) {
        this.other = other;
    }
    /**
     * 劳务
     */
    public java.math.BigDecimal getLabourservices() {
        return labourservices;
    }

    /**
     * 劳务
     */
    public void setLabourservices(java.math.BigDecimal labourservices) {
        this.labourservices = labourservices;
    }
    /**
     * 材料
     */
    public java.math.BigDecimal getMaterial() {
        return material;
    }

    /**
     * 材料
     */
    public void setMaterial(java.math.BigDecimal material) {
        this.material = material;
    }
    /**
     * 专业分包
     */
    public java.math.BigDecimal getProfessional() {
        return professional;
    }

    /**
     * 专业分包
     */
    public void setProfessional(java.math.BigDecimal professional) {
        this.professional = professional;
    }
    /**
     * 其它费用
     */
    public java.math.BigDecimal getOthercost() {
        return othercost;
    }

    /**
     * 其它费用
     */
    public void setOthercost(java.math.BigDecimal othercost) {
        this.othercost = othercost;
    }
    /**
     * 当期
     */
    public java.math.BigDecimal getCurrent() {
        return current;
    }

    /**
     * 当期
     */
    public void setCurrent(java.math.BigDecimal current) {
        this.current = current;
    }
    /**
     * 累计
     */
    public java.math.BigDecimal getCumulative() {
        return cumulative;
    }

    /**
     * 累计
     */
    public void setCumulative(java.math.BigDecimal cumulative) {
        this.cumulative = cumulative;
    }
    /**
     * 应对措施
     */
    public java.math.BigDecimal getAnswer() {
        return answer;
    }

    /**
     * 应对措施
     */
    public void setAnswer(java.math.BigDecimal answer) {
        this.answer = answer;
    }
    /**
     * 备注
     */
    public String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(String remarks) {
        this.remarks = remarks;
    }
    /**
     * 工资
     */
    public java.math.BigDecimal getSalary() {
        return salary;
    }

    /**
     * 工资
     */
    public void setSalary(java.math.BigDecimal salary) {
        this.salary = salary;
    }
    /**
     * 土建安装其他总计
     */
    public java.math.BigDecimal getCioAmount() {
        return cioAmount;
    }

    /**
     * 土建安装其他总计
     */
    public void setCioAmount(java.math.BigDecimal cioAmount) {
        this.cioAmount = cioAmount;
    }
    /**
     * 生效时间
     */
    public java.util.Date getEffectTime() {
        return effectTime;
    }

    /**
     * 生效时间
     */
    public void setEffectTime(java.util.Date effectTime) {
        this.effectTime = effectTime;
    }
    /**
     * 变更原因
     */
    public String getChangeReason() {
        return changeReason;
    }

    /**
     * 变更原因
     */
    public void setChangeReason(String changeReason) {
        this.changeReason = changeReason;
    }

    public String getCollectbranchTime1() {
        return collectbranchTime1;
    }

    public void setCollectbranchTime1(String collectbranchTime1) {
        this.collectbranchTime1 = collectbranchTime1;
    }

    public Integer getPastFlag() {
        return pastFlag;
    }

    public void setPastFlag(Integer pastFlag) {
        this.pastFlag = pastFlag;
    }
}

==> ejc-businessplan-impl-3.0.0-20251128.085607-235-sources.jar: com/ejianc/business/change/vo/ChangeFundsplanningdetailVO.java <==
package com.ejianc.business.change.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 项目资金管理策划变更子表
 *
 * @author generator
 *
 */
public class ChangeFundsplanningdetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long mid; // 主表id
    private String sort; // 序号
    private java.util.Date collectbranchTime; // 收支时间(日期)
    private java.lang.String collectbranchTime1; // 收支时间(文本)
    private String imagenode; // 形象进度节点情况
    private java.math.BigDecimal plancomplete; // 计划完成产值
    private java.math.BigDecimal civilengineering; // 土建
    private java.math.BigDecimal installation; // 安装
    private java.math.BigDecimal other; // 其它
    private java.math.BigDecimal labourservices; // 劳务
    private java.math.BigDecimal material; // 材料
    private java.math.BigDecimal professional; // 专业分包
    private java.math.BigDecimal othercost; // 其它费用
    private java.math.BigDecimal current; // 当期
    private java.math.BigDecimal cumulative; // 累计
    private java.lang.String answer; // 应对措施
    private String remarks; // 备注
    private java.math.BigDecimal salary; // 工资
    private java.math.BigDecimal cioAmount; // 土建安装其他总计
    private java.util.Date effectTime; // 生效时间
    private String changeReason; // 变更原因
    private String billCode;
    private String errorMsg;

    private java.lang.Integer pastFlag;//是否为往期数据：1是，0否

    public String getErrorMsg() {
        return errorMsg;
    }

    public void setErrorMsg(String errorMsg) {
        this.errorMsg = errorMsg;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    /**
     * 主表id
     */
    public Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(Long mid) {
        this.mid = mid;
    }
    /**
     * 序号
     */
    public String getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(String sort) {
        this.sort = sort;
    }
    /**
     * 收支时间(日期)
     */
    public java.util.Date getCollectbranchTime() {
        return collectbranchTime;
    }

    /**
     * 收支时间(日期)
     */
    public void setCollectbranchTime(java.util.Date collectbranchTime) {
        this.collectbranchTime = collectbranchTime;
    }
    /**
     * 形象进度节点情况
     */
    public String getImagenode() {
        return imagenode;
    }

    /**
     * 形象进度节点情况
     */
    public void setImagenode(String imagenode) {
        this.imagenode = imagenode;
    }
    /**
     * 计划完成产值
     */
    public java.math.BigDecimal getPlancomplete() {
        return plancomplete;
    }

    /**
     * 计划完成产值
     */
    public void setPlancomplete(java.math.BigDecimal plancomplete) {
        this.plancomplete = plancomplete;
    }
    /**
     * 土建
     */
    public java.math.BigDecimal getCivilengineering() {
        return civilengineering;
    }

    /**
     * 土建
     */
    public void setCivilengineering(java.math.BigDecimal civilengineering) {
        this.civilengineering = civilengineering;
    }
    /**
     * 安装
     */
    public java.math.BigDecimal getInstallation() {
        return installation;
    }

    /**
     * 安装
     */
    public void setInstallation(java.math.BigDecimal installation) {
        this.installation = installation;
    }
    /**
     * 其它
     */
    public java.math.BigDecimal getOther() {
        return other;
    }

    /**
     * 其它
     */
    public void setOther(java.math.BigDecimal other) {
        this.other = other;
    }
    /**
     * 劳务
     */
    public java.math.BigDecimal getLabourservices() {
        return labourservices;
    }

    /**
     * 劳务
     */
    public void setLabourservices(java.math.BigDecimal labourservices) {
        this.labourservices = labourservices;
    }
    /**
     * 材料
     */
    public java.math.BigDecimal getMaterial() {
        return material;
    }

    /**
     * 材料
     */
    public void setMaterial(java.math.BigDecimal material) {
        this.material = material;
    }
    /**
     * 专业分包
     */
    public java.math.BigDecimal getProfessional() {
        return professional;
    }

    /**
     * 专业分包
     */
    public void setProfessional(java.math.BigDecimal professional) {
        this.professional = professional;
    }
    /**
     * 其它费用
     */
    public java.math.BigDecimal getOthercost() {
        return othercost;
    }

    /**
     * 其它费用
     */
    public void setOthercost(java.math.BigDecimal othercost) {
        this.othercost = othercost;
    }
    /**
     * 当期
     */
    public java.math.BigDecimal getCurrent() {
        return current;
    }

    /**
     * 当期
     */
    public void setCurrent(java.math.BigDecimal current) {
        this.current = current;
    }
    /**
     * 累计
     */
    public java.math.BigDecimal getCumulative() {
        return cumulative;
    }

    /**
     * 累计
     */
    public void setCumulative(java.math.BigDecimal cumulative) {
        this.cumulative = cumulative;
    }
    /**
     * 应对措施
     */
    public java.lang.String getAnswer() {
        return answer;
    }

    /**
     * 应对措施
     */
    public void setAnswer(java.lang.String answer) {
        this.answer = answer;
    }
    /**
     * 备注
     */
    public String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(String remarks) {
        this.remarks = remarks;
    }
    /**
     * 工资
     */
    public java.math.BigDecimal getSalary() {
        return salary;
    }

    /**
     * 工资
     */
    public void setSalary(java.math.BigDecimal salary) {
        this.salary = salary;
    }
    /**
     * 土建安装其他总计
     */
    public java.math.BigDecimal getCioAmount() {
        return cioAmount;
    }

    /**
     * 土建安装其他总计
     */
    public void setCioAmount(java.math.BigDecimal cioAmount) {
        this.cioAmount = cioAmount;
    }
    /**
     * 生效时间
     */
    public java.util.Date getEffectTime() {
        return effectTime;
    }

    /**
     * 生效时间
     */
    public void setEffectTime(java.util.Date effectTime) {
        this.effectTime = effectTime;
    }
    /**
     * 变更原因
     */
    public String getChangeReason() {
        return changeReason;
    }

    /**
     * 变更原因
     */
    public void setChangeReason(String changeReason) {
        this.changeReason = changeReason;
    }

    public String getCollectbranchTime1() {
        return collectbranchTime1;
    }

    public void setCollectbranchTime1(String collectbranchTime1) {
        this.collectbranchTime1 = collectbranchTime1;
    }

    public Integer getPastFlag() {
        return pastFlag;
    }

    public void setPastFlag(Integer pastFlag) {
        this.pastFlag = pastFlag;
    }
}
